@@ -1,5 +1,6 @@
 /* ELF core file support for BFD.
-   Copyright (C) 1995, 1996, 1997, 1998 Free Software Foundation, Inc.
+   Copyright 1995, 1996, 1997, 1998, 2000, 2001
+   Free Software Foundation, Inc.
 
 This file is part of BFD, the Binary File Descriptor library.
 
@@ -205,7 +206,7 @@ elf_core_file_p (abfd)
   /* Process each program header.  */
   for (phindex = 0; phindex < i_ehdrp->e_phnum; ++phindex)
     {
-      if (!_bfd_elfcore_section_from_phdr (abfd, i_phdrp + phindex, phindex))
+      if (! bfd_section_from_phdr (abfd, i_phdrp + phindex, phindex))
 	goto fail;
     }
 
