@@ -1,4 +1,4 @@
 
 Relocation section '.rel.*text' at offset 0x.* contains 1 entries:
   Offset    Info  Type            Symbol's Value  Symbol's Name.*
-  00000004  00.* R_.*00000000  external_symbol.*
+  00000004  [0-9A-Fa-f]+ *R_.*00000000  external_symbol.*
